@@ -1,5 +1,3 @@
-context("window_lsm")
-
 window <- matrix(1, nrow = 11, ncol = 11)
 
 window_even <-  matrix(1, nrow = 10, ncol = 10)
@@ -22,17 +20,14 @@ test_that("window_lsm takes argument", {
 
 test_that("window_lsm returns works for all data types", {
 
-    expect_is(window_lsm(landscape, window = window, what = "lsm_l_pr"),
-              class = "list")
+    expect_type(window_lsm(landscape, window = window, what = "lsm_l_pr"),
+                type = "list")
 
-    expect_is(window_lsm(landscape_stack, window = window, what = "lsm_l_pr"),
-              class = "list")
+    expect_type(window_lsm(landscape_stack, window = window, what = "lsm_l_pr"),
+                type = "list")
 
-    expect_is(window_lsm(landscape_brick, window = window, what = "lsm_l_pr"),
-              class = "list")
-
-    expect_is(window_lsm(landscape_list, window = window, what = "lsm_l_pr"),
-              class = "list")
+    expect_type(window_lsm(landscape_list, window = window, what = "lsm_l_pr"),
+                type = "list")
 })
 
 test_that("window_lsm returns all errors", {
